@@ -27,50 +27,51 @@ class ComplianceClient:
 
     def oscap_scan(self):
         self._assert_oscap_rpms_exist()
-        policies = self.get_policies()
-        if not policies:
+        initial_profiles = self.get_initial_profiles()
+        matching_os_profiles = self.get_profiles_matching_os()
+        profiles = self.profile_union_by_ref_id(matching_os_profiles, initial_profiles)
+        if not profiles:
             logger.error("System is not associated with any profiles. Assign profiles using the Compliance web UI.\n")
             exit(constants.sig_kill_bad)
-        for policy in policies:
+        for profile in profiles:
             self.run_scan(
-                policy['attributes']['ref_id'],
-                self.find_scap_policy(policy['attributes']['ref_id']),
-                '/var/tmp/oscap_results-{0}.xml'.format(policy['attributes']['ref_id']),
-                tailoring_file_path=self.download_tailoring_file(policy)
+                profile['attributes']['ref_id'],
+                self.find_scap_policy(profile['attributes']['ref_id']),
+                '/var/tmp/oscap_results-{0}.xml'.format(profile['attributes']['ref_id']),
+                tailoring_file_path=self.download_tailoring_file(profile)
             )
 
         return self.archive.create_tar_file(), COMPLIANCE_CONTENT_TYPE
 
-    def download_tailoring_file(self, policy):
-        if 'tailored' not in policy['attributes'] or policy['attributes']['tailored'] is False:
+    def download_tailoring_file(self, profile):
+        if ('tailored' not in profile['attributes'] or profile['attributes']['tailored'] is False or
+                ('os_minor_version' in profile['attributes'] and profile['attributes']['os_minor_version'] != self.os_minor_version())):
             return None
 
         # Download tailoring file to pass as argument to run_scan
         logger.debug(
-            "Policy {0} is a tailored policy. Starting tailoring file download...".format(policy['attributes']['ref_id'])
+            "Policy {0} is a tailored policy. Starting tailoring file download...".format(profile['attributes']['ref_id'])
         )
-        tailoring_file_path = "/var/tmp/oscap_tailoring_file-{0}.xml".format(policy['attributes']['ref_id'])
+        tailoring_file_path = "/var/tmp/oscap_tailoring_file-{0}.xml".format(profile['attributes']['ref_id'])
         response = self.conn.session.get(
-            "https://{0}/compliance/profiles/{1}/tailoring_file".format(self.config.base_url, policy['id'])
+            "https://{0}/compliance/profiles/{1}/tailoring_file".format(self.config.base_url, profile['id'])
         )
         logger.debug("Response code: {0}".format(response.status_code))
         if response.content is None:
-            logger.info("Problem downloading tailoring file for {0} to {1}".format(policy['attributes']['ref_id'], tailoring_file_path))
+            logger.info("Problem downloading tailoring file for {0} to {1}".format(profile['attributes']['ref_id'], tailoring_file_path))
             return None
 
         with open(tailoring_file_path, mode="w+b") as f:
             f.write(response.content)
-            logger.info("Saved tailoring file for {0} to {1}".format(policy['attributes']['ref_id'], tailoring_file_path))
+            logger.info("Saved tailoring file for {0} to {1}".format(profile['attributes']['ref_id'], tailoring_file_path))
 
-        logger.debug("Policy {0} tailoring file download finished".format(policy['attributes']['ref_id']))
+        logger.debug("Policy {0} tailoring file download finished".format(profile['attributes']['ref_id']))
 
         return tailoring_file_path
 
-    # TODO: Not a typo! This endpoint gives OSCAP policies, not profiles
-    # We need to update compliance-backend to fix this
-    def get_policies(self):
+    def get_profiles(self, search):
         response = self.conn.session.get("https://{0}/compliance/profiles".format(self.config.base_url),
-                                         params={'search': 'system_names={0} external=false canonical=false'.format(self.hostname)})
+                                         params={'search': search})
         logger.debug("Content of the response: {0} - {1}".format(response,
                                                                  response.json()))
         if response.status_code == 200:
@@ -78,12 +79,30 @@ class ComplianceClient:
         else:
             return []
 
+    def get_initial_profiles(self):
+        return self.get_profiles('system_names={0} canonical=false external=false'.format(self.hostname))
+
+    def get_profiles_matching_os(self):
+        return self.get_profiles('system_names={0} canonical=false os_minor_version={1}'.format(self.hostname, self.os_minor_version()))
+
+    def profile_union_by_ref_id(self, prioritized_profiles, merged_profiles):
+        profiles = dict((p['attributes']['ref_id'], p) for p in merged_profiles)
+        profiles.update(dict((p['attributes']['ref_id'], p) for p in prioritized_profiles))
+
+        return list(profiles.values())
+
     def os_release(self):
         _, version, _ = linux_distribution()
-        return findall("^[6-8]", version)[0]
+        return version
+
+    def os_major_version(self):
+        return findall("^[6-8]", self.os_release())[0]
+
+    def os_minor_version(self):
+        return findall("\d+$", self.os_release())[0]
 
     def profile_files(self):
-        return glob("{0}*rhel{1}*.xml".format(POLICY_FILE_LOCATION, self.os_release()))
+        return glob("{0}*rhel{1}*.xml".format(POLICY_FILE_LOCATION, self.os_major_version()))
 
     def find_scap_policy(self, profile_ref_id):
         grepcmd = 'grep ' + profile_ref_id + ' ' + ' '.join(self.profile_files())
