@@ -103,7 +103,8 @@ rhel_release_map = {
     "3.10.0-1160": "7.9",
     "4.18.0-80": "8.0",
     "4.18.0-147": "8.1",
-    "4.18.0-193": "8.2"
+    "4.18.0-193": "8.2",
+    "4.18.0-240": "8.3",
 }
 
 release_to_kernel_map = dict((v, k) for k, v in rhel_release_map.items())
