@@ -20,6 +20,7 @@ class Specs(SpecSet):
     abrt_status_bare = RegistryPoint()
     alternatives_display_python = RegistryPoint()
     amq_broker = RegistryPoint(multi_output=True)
+    ansible_host = RegistryPoint()
     auditctl_status = RegistryPoint()
     auditd_conf = RegistryPoint()
     audit_log = RegistryPoint(filterable=True)
@@ -31,6 +32,7 @@ class Specs(SpecSet):
     aws_instance_type = RegistryPoint()
     awx_manage_check_license = RegistryPoint()
     azure_instance_type = RegistryPoint()
+    azure_instance_plan = RegistryPoint()
     bios_uuid = RegistryPoint()
     blkid = RegistryPoint()
     bond = RegistryPoint(multi_output=True)
@@ -128,6 +130,7 @@ class Specs(SpecSet):
     dmesg_log = RegistryPoint(filterable=True)
     dmidecode = RegistryPoint()
     dmsetup_info = RegistryPoint()
+    dmsetup_status = RegistryPoint()
     dnf_conf = RegistryPoint(filterable=True)
     dnf_modules = RegistryPoint()
     dnf_module_list = RegistryPoint()
@@ -184,6 +187,7 @@ class Specs(SpecSet):
     freeipa_healthcheck_log = RegistryPoint()
     fstab = RegistryPoint()
     galera_cnf = RegistryPoint()
+    gcp_license_codes = RegistryPoint()
     getcert_list = RegistryPoint()
     getconf_page_size = RegistryPoint()
     getenforce = RegistryPoint()
@@ -198,6 +202,7 @@ class Specs(SpecSet):
     gluster_peer_status = RegistryPoint()
     gnocchi_conf = RegistryPoint(filterable=True)
     gnocchi_metricd_log = RegistryPoint(filterable=True)
+    greenboot_status = RegistryPoint(filterable=True)
     grub_conf = RegistryPoint()
     grub_config_perms = RegistryPoint()
     grub_efi_conf = RegistryPoint()
@@ -242,6 +247,7 @@ class Specs(SpecSet):
     init_ora = RegistryPoint()
     initscript = RegistryPoint(multi_output=True)
     init_process_cgroup = RegistryPoint()
+    insights_client_conf = RegistryPoint(filterable=True)
     installed_rpms = RegistryPoint()
     interrupts = RegistryPoint()
     ip6tables_permanent = RegistryPoint()
@@ -285,7 +291,7 @@ class Specs(SpecSet):
     ksmstate = RegistryPoint()
     kubepods_cpu_quota = RegistryPoint(multi_output=True)
     lastupload = RegistryPoint(multi_output=True)
-    ld_library_path_of_pid = RegistryPoint()
+    ld_library_path_of_user = RegistryPoint()
     libssh_client_config = RegistryPoint(filterable=True)
     libssh_server_config = RegistryPoint(filterable=True)
     libvirtd_log = RegistryPoint(filterable=True)
@@ -312,6 +318,7 @@ class Specs(SpecSet):
     ls_usr_bin = RegistryPoint(filterable=True)
     ls_usr_lib64 = RegistryPoint(filterable=True)
     ls_usr_sbin = RegistryPoint(filterable=True)
+    ls_var_cache_pulp = RegistryPoint()
     ls_var_lib_mongodb = RegistryPoint()
     ls_var_lib_nova_instances = RegistryPoint()
     ls_var_log = RegistryPoint()
@@ -331,6 +338,7 @@ class Specs(SpecSet):
     lsmod = RegistryPoint()
     lsof = RegistryPoint(filterable=True)
     lspci = RegistryPoint()
+    lspci_vmmkn = RegistryPoint()
     lssap = RegistryPoint()
     lsscsi = RegistryPoint()
     lsvmbus = RegistryPoint()
@@ -480,6 +488,8 @@ class Specs(SpecSet):
     pcs_status = RegistryPoint()
     php_ini = RegistryPoint(filterable=True)
     pluginconf_d = RegistryPoint(multi_output=True)
+    pmlog_summary = RegistryPoint()
+    pmrep_metrics = RegistryPoint()
     podman_container_inspect = RegistryPoint(multi_output=True)
     podman_image_inspect = RegistryPoint(multi_output=True)
     podman_list_containers = RegistryPoint()
@@ -543,6 +553,7 @@ class Specs(SpecSet):
     rhn_taskomatic_daemon_log = RegistryPoint(filterable=False)
     rhosp_release = RegistryPoint()
     rhsm_conf = RegistryPoint()
+    rhsm_katello_default_ca_cert = RegistryPoint()
     rhsm_log = RegistryPoint(filterable=True)
     rhsm_releasever = RegistryPoint()
     rndc_status = RegistryPoint()
@@ -553,6 +564,7 @@ class Specs(SpecSet):
     samba = RegistryPoint(filterable=True)
     sap_dev_disp = RegistryPoint(multi_output=True, filterable=True)
     sap_dev_rd = RegistryPoint(multi_output=True, filterable=True)
+    sap_hana_landscape = RegistryPoint(multi_output=True)
     sap_hdb_version = RegistryPoint(multi_output=True)
     sap_host_profile = RegistryPoint(filterable=True)
     sapcontrol_getsystemupdatelist = RegistryPoint()
@@ -560,9 +572,12 @@ class Specs(SpecSet):
     saphostexec_status = RegistryPoint()
     saphostexec_version = RegistryPoint()
     sat5_insights_properties = RegistryPoint()
+    satellite_compute_resources = RegistryPoint()
     satellite_content_hosts_count = RegistryPoint()
+    satellite_custom_ca_chain = RegistryPoint()
     satellite_mongodb_storage_engine = RegistryPoint()
     satellite_non_yum_type_repos = RegistryPoint()
+    satellite_settings = RegistryPoint()
     satellite_version_rb = RegistryPoint()
     satellite_custom_hiera = RegistryPoint()
     scheduler = RegistryPoint(multi_output=True)
