@@ -9,11 +9,13 @@ data sources that standard Insights `Parsers` resolve against.
 """
 
 import logging
+import os
 import re
 import json
+import signal
 
 from grp import getgrgid
-from os import stat, listdir as os_listdir
+from os import stat
 from pwd import getpwuid
 
 import yaml
@@ -36,6 +38,7 @@ from insights.parsers.lsmod import LsMod
 from insights.combiners.satellite_version import SatelliteVersion, CapsuleVersion
 from insights.parsers.mount import Mount
 from insights.specs import Specs
+import datetime
 
 
 logger = logging.getLogger(__name__)
@@ -92,7 +95,7 @@ def _get_package(broker, command):
     ctx = broker[HostContext]
     resolved = ctx.shell_out("/usr/bin/readlink -e {0}".format(command))
     if resolved:
-        pkg = ctx.shell_out("/usr/bin/rpm -qf {0}".format(resolved[0]))
+        pkg = ctx.shell_out("/usr/bin/rpm -qf {0}".format(resolved[0]), signum=signal.SIGTERM)
         if pkg:
             return pkg[0]
     raise SkipComponent
@@ -157,6 +160,7 @@ class DefaultSpecs(Specs):
         raise SkipComponent()
 
     azure_instance_type = simple_command("/usr/bin/curl -s -H Metadata:true http://169.254.169.254/metadata/instance/compute/vmSize?api-version=2018-10-01&format=text --connect-timeout 5", deps=[is_azure])
+    azure_instance_plan = simple_command("/usr/bin/curl -s -H Metadata:true http://169.254.169.254/metadata/instance/compute/plan?api-version=2018-10-01&format=json --connect-timeout 5", deps=[is_azure])
     bios_uuid = simple_command("/usr/sbin/dmidecode -s system-uuid")
     blkid = simple_command("/sbin/blkid -c /dev/null")
     bond = glob_file("/proc/net/bonding/bond*")
@@ -218,7 +222,7 @@ class DefaultSpecs(Specs):
     ceph_osd_tree = simple_command("/usr/bin/ceph osd tree -f json")
     ceph_s = simple_command("/usr/bin/ceph -s -f json")
     ceph_v = simple_command("/usr/bin/ceph -v")
-    certificates_enddate = simple_command("/usr/bin/find /etc/origin/node /etc/origin/master /etc/pki /etc/ipa -type f -exec /usr/bin/openssl x509 -noout -enddate -in '{}' \; -exec echo 'FileName= {}' \;")
+    certificates_enddate = simple_command("/usr/bin/find /etc/origin/node /etc/origin/master /etc/pki /etc/ipa -type f -exec /usr/bin/openssl x509 -noout -enddate -in '{}' \; -exec echo 'FileName= {}' \;", keep_rc=True)
     chkconfig = simple_command("/sbin/chkconfig --list")
     chrony_conf = simple_file("/etc/chrony.conf")
     chronyc_sources = simple_command("/usr/bin/chronyc sources")
@@ -304,13 +308,22 @@ class DefaultSpecs(Specs):
         Returns:
             list: A list of related corosync-cmapctl commands based the RHEL version.
         """
-        if broker.get(IsRhel7):
-            return ["/usr/sbin/corosync-cmapctl", 'corosync-cmapctl -d runtime.schedmiss.timestamp', 'corosync-cmapctl -d runtime.schedmiss.delay']
-        if broker.get(IsRhel8):
-            return ["/usr/sbin/corosync-cmapctl", '/usr/sbin/corosync-cmapctl -m stats', '/usr/sbin/corosync-cmapctl -C schedmiss']
-        raise SkipComponent()
-    corosync_cmapctl = foreach_execute(corosync_cmapctl_cmd_list, "%s")
+        corosync_cmd = '/usr/sbin/corosync-cmapctl'
+        if os.path.exists(corosync_cmd):
+            if broker.get(IsRhel7):
+                return [
+                    corosync_cmd,
+                    ' '.join([corosync_cmd, '-d runtime.schedmiss.timestamp']),
+                    ' '.join([corosync_cmd, '-d runtime.schedmiss.delay'])]
+            if broker.get(IsRhel8):
+                return [
+                    corosync_cmd,
+                    ' '.join([corosync_cmd, '-m stats']),
+                    ' '.join([corosync_cmd, '-C schedmiss'])]
 
+        raise SkipComponent()
+
+    corosync_cmapctl = foreach_execute(corosync_cmapctl_cmd_list, "%s")
     corosync_conf = simple_file("/etc/corosync/corosync.conf")
     cpu_cores = glob_file("sys/devices/system/cpu/cpu[0-9]*/online")
     cpu_siblings = glob_file("sys/devices/system/cpu/cpu[0-9]*/topology/thread_siblings_list")
@@ -341,6 +354,7 @@ class DefaultSpecs(Specs):
     dmesg_log = simple_file("/var/log/dmesg")
     dmidecode = simple_command("/usr/sbin/dmidecode")
     dmsetup_info = simple_command("/usr/sbin/dmsetup info -C")
+    dmsetup_status = simple_command("/usr/sbin/dmsetup status")
     dnf_conf = simple_file("/etc/dnf/dnf.conf")
     dnf_modules = glob_file("/etc/dnf/modules.d/*.module")
     docker_info = simple_command("/usr/bin/docker info")
@@ -410,6 +424,17 @@ class DefaultSpecs(Specs):
     gluster_v_info = simple_command("/usr/sbin/gluster volume info")
     gnocchi_conf = first_file(["/var/lib/config-data/puppet-generated/gnocchi/etc/gnocchi/gnocchi.conf", "/etc/gnocchi/gnocchi.conf"])
     gnocchi_metricd_log = first_file(["/var/log/containers/gnocchi/gnocchi-metricd.log", "/var/log/gnocchi/metricd.log"])
+
+    @datasource(CloudProvider, HostContext)
+    def is_gcp(broker):
+        """ bool: Returns True if this node is identified as running in GCP """
+        cp = broker[CloudProvider]
+        if cp and cp.cloud_provider == CloudProvider.GOOGLE:
+            return True
+        raise SkipComponent()
+
+    gcp_license_codes = simple_command("/usr/bin/curl -s curl -H Metadata-Flavor: Google http://metadata.google.internal/computeMetadata/v1/instance/licenses/?recursive=True --connect-timeout 5", deps=[is_gcp])
+    greenboot_status = simple_command("/usr/libexec/greenboot/greenboot-status")
     grub_conf = simple_file("/boot/grub/grub.conf")
     grub_config_perms = simple_command("/bin/ls -l /boot/grub2/grub.cfg")  # only RHEL7 and updwards
     grub_efi_conf = simple_file("/boot/efi/EFI/redhat/grub.conf")
@@ -475,6 +500,7 @@ class DefaultSpecs(Specs):
     imagemagick_policy = glob_file(["/etc/ImageMagick/policy.xml", "/usr/lib*/ImageMagick-6.5.4/config/policy.xml"])
     initctl_lst = simple_command("/sbin/initctl --system list")
     init_process_cgroup = simple_file("/proc/1/cgroup")
+    insights_client_conf = simple_file('/etc/insights-client/insights-client.conf')
     interrupts = simple_file("/proc/interrupts")
     ip_addr = simple_command("/sbin/ip addr")
     ip_addresses = simple_command("/bin/hostname -I")
@@ -502,20 +528,6 @@ class DefaultSpecs(Specs):
     kubepods_cpu_quota = glob_file("/sys/fs/cgroup/cpu/kubepods.slice/kubepods-burstable.slice/kubepods-burstable-pod[a-f0-9_]*.slice/cpu.cfs_quota_us")
     last_upload_globs = ["/etc/redhat-access-insights/.lastupload", "/etc/insights-client/.lastupload"]
     lastupload = glob_file(last_upload_globs)
-
-    @datasource()
-    def ld_library_path_of_pid(broker):
-        pids = [p for p in sorted(os_listdir('/proc/')) if p.isdigit()]
-        llds = []
-        for p in pids:
-            with open('/proc/{0}/environ'.format(p), 'r') as fp:
-                vars = fp.read()
-                lld = [v.split('=', 1)[-1] for v in vars.split('\x00') if v.startswith('LD_LIBRARY_PATH=')]
-                llds.append("{0} {1}".format(p, lld[0])) if lld else None
-        if llds:
-            return DatasourceProvider('\n'.join(llds), relative_path='insights_commands/cat_all_PID_LD_LIBRARY_PATH')
-        raise SkipComponent
-
     libssh_client_config = simple_file("/etc/libssh/libssh_client.config")
     libssh_server_config = simple_file("/etc/libssh/libssh_server.config")
     libvirtd_log = simple_file("/var/log/libvirt/libvirtd.log")
@@ -530,7 +542,7 @@ class DefaultSpecs(Specs):
     etc_and_sub_dirs = sorted(["/etc", "/etc/pki/tls/private", "/etc/pki/tls/certs",
         "/etc/pki/ovirt-vmconsole", "/etc/nova/migration", "/etc/sysconfig",
         "/etc/cloud/cloud.cfg.d", "/etc/rc.d/init.d"])
-    ls_etc = simple_command("/bin/ls -lan {0}".format(' '.join(etc_and_sub_dirs)))
+    ls_etc = simple_command("/bin/ls -lan {0}".format(' '.join(etc_and_sub_dirs)), keep_rc=True)
     ls_ipa_idoverride_memberof = simple_command("/bin/ls -lan /usr/share/ipa/ui/js/plugins/idoverride-memberof")
     ls_lib_firmware = simple_command("/bin/ls -lanR /lib/firmware")
     ls_ocp_cni_openshift_sdn = simple_command("/bin/ls -l /var/lib/cni/networks/openshift-sdn")
@@ -542,6 +554,7 @@ class DefaultSpecs(Specs):
     ls_tmp = simple_command("/bin/ls -la /tmp")
     ls_usr_bin = simple_command("/bin/ls -lan /usr/bin")
     ls_usr_lib64 = simple_command("/bin/ls -lan /usr/lib64")
+    ls_var_cache_pulp = simple_command("/bin/ls -lan /var/cache/pulp")
     ls_var_lib_mongodb = simple_command("/bin/ls -la /var/lib/mongodb")
     ls_var_lib_nova_instances = simple_command("/bin/ls -laRZ /var/lib/nova/instances")
     ls_var_log = simple_command("/bin/ls -la /var/log /var/log/audit")
@@ -558,7 +571,7 @@ class DefaultSpecs(Specs):
     lsmod = simple_command("/sbin/lsmod")
     lsof = simple_command("/usr/sbin/lsof")
     lspci = simple_command("/sbin/lspci -k")
-    lssap = simple_command("/usr/sap/hostctrl/exe/lssap")
+    lspci_vmmkn = simple_command("/sbin/lspci -vmmkn")
     lsscsi = simple_command("/usr/bin/lsscsi")
     lsvmbus = simple_command("/usr/sbin/lsvmbus -vv")
     lvm_conf = simple_file("/etc/lvm/lvm.conf")
@@ -572,7 +585,7 @@ class DefaultSpecs(Specs):
     def md5chk_file_list(broker):
         """ Provide a list of files to be processed by the ``md5chk_files`` spec """
         return ["/etc/pki/product/69.pem", "/etc/pki/product-default/69.pem", "/usr/lib/libsoftokn3.so", "/usr/lib64/libsoftokn3.so", "/usr/lib/libfreeblpriv3.so", "/usr/lib64/libfreeblpriv3.so"]
-    md5chk_files = foreach_execute(md5chk_file_list, "/usr/bin/md5sum %s")
+    md5chk_files = foreach_execute(md5chk_file_list, "/usr/bin/md5sum %s", keep_rc=True)
     mdstat = simple_file("/proc/mdstat")
 
     @datasource(Mdstat, HostContext)
@@ -594,7 +607,8 @@ class DefaultSpecs(Specs):
     mongod_conf = glob_file([
                             "/etc/mongod.conf",
                             "/etc/mongodb.conf",
-                            "/etc/opt/rh/rh-mongodb26/mongod.conf"
+                            "/etc/opt/rh/rh-mongodb26/mongod.conf",
+                            "/etc/opt/rh/rh-mongodb34/mongod.conf"
                             ])
     mount = simple_command("/bin/mount")
     mounts = simple_file("/proc/mounts")
@@ -710,18 +724,50 @@ class DefaultSpecs(Specs):
     pcs_status = simple_command("/usr/sbin/pcs status")
     php_ini = first_file(["/etc/opt/rh/php73/php.ini", "/etc/opt/rh/php72/php.ini", "/etc/php.ini"])
     pluginconf_d = glob_file("/etc/yum/pluginconf.d/*.conf")
+
+    @datasource(Ps, HostContext)
+    def pmlog_summary_file(broker):
+        """
+        Determines the name for the pmlogger file and checks for its existance
+
+        Returns the name of the latest pmlogger summary file if a running ``pmlogger``
+        process is detected on the system.
+
+        Returns:
+            str: Full path to the latest pmlogger file
+
+        Raises:
+            SkipComponent: raises this exception when the command is not present or
+                the file is not present
+        """
+        ps = broker[Ps]
+        if ps.search(COMMAND__contains='pmlogger'):
+            pcp_log_date = (datetime.date.today() - datetime.timedelta(days=1)).strftime("%Y%m%d")
+            file = "/var/log/pcp/pmlogger/ros/%s.index" % (pcp_log_date)
+            try:
+                if os.path.exists(file) and os.path.isfile(file):
+                    return file
+            except Exception as e:
+                SkipComponent("Failed to check for pmlogger file existance: {0}".format(str(e)))
+
+        raise SkipComponent
+
+    pmlog_summary = command_with_args(
+        "/usr/bin/pmlogsummary %s mem.util.used mem.physmem kernel.all.cpu.user kernel.all.cpu.sys kernel.all.cpu.nice kernel.all.cpu.steal kernel.all.cpu.idle disk.all.total mem.util.cached mem.util.bufmem mem.util.free kernel.all.cpu.wait.total",
+        pmlog_summary_file)
+    pmrep_metrics = simple_command("pmrep -t 1s -T 1s network.interface.out.packets network.interface.collisions swap.pagesout -o csv")
     postconf_builtin = simple_command("/usr/sbin/postconf -C builtin")
     postconf = simple_command("/usr/sbin/postconf")
     postgresql_conf = first_file([
-                                 "/var/lib/pgsql/data/postgresql.conf",
-                                 "/opt/rh/postgresql92/root/var/lib/pgsql/data/postgresql.conf",
-                                 "database/postgresql.conf"
-                                 ])
-    postgresql_log = first_of([
-                              glob_file("/var/lib/pgsql/data/pg_log/postgresql-*.log"),
-                              glob_file("/opt/rh/postgresql92/root/var/lib/pgsql/data/pg_log/postgresql-*.log"),
-                              glob_file("/database/postgresql-*.log")
-                              ])
+        "/var/opt/rh/rh-postgresql12/lib/pgsql/data/postgresql.conf",
+        "/var/lib/pgsql/data/postgresql.conf",
+    ])
+    postgresql_log = first_of(
+        [
+            glob_file("/var/opt/rh/rh-postgresql12/lib/pgsql/data/log/postgresql-*.log"),
+            glob_file("/var/lib/pgsql/data/pg_log/postgresql-*.log"),
+        ]
+    )
     puppetserver_config = simple_file("/etc/sysconfig/puppetserver")
     proc_netstat = simple_file("proc/net/netstat")
     proc_slabinfo = simple_file("proc/slabinfo")
@@ -731,9 +777,9 @@ class DefaultSpecs(Specs):
     pulp_worker_defaults = simple_file("etc/default/pulp_workers")
     puppet_ca_cert_expire_date = simple_command("/usr/bin/openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout")
     pvs_noheadings = simple_command("/sbin/pvs --nameprefixes --noheadings --separator='|' -a -o pv_all,vg_name --config=\"global{locking_type=0}\"")
+    rhsm_katello_default_ca_cert = simple_command("/usr/bin/openssl x509 -in /etc/rhsm/ca/katello-default-ca.pem -noout -issuer")
     qemu_conf = simple_file("/etc/libvirt/qemu.conf")
     qemu_xml = glob_file(r"/etc/libvirt/qemu/*.xml")
-    qpid_stat_g = simple_command("/usr/bin/qpid-stat -g --ssl-certificate=/etc/pki/katello/qpid_client_striped.crt -b amqps://localhost:5671")
     qpidd_conf = simple_file("/etc/qpid/qpidd.conf")
     rabbitmq_env = simple_file("/etc/rabbitmq/rabbitmq-env.conf")
     rabbitmq_report = simple_command("/usr/sbin/rabbitmqctl report")
@@ -751,19 +797,73 @@ class DefaultSpecs(Specs):
     rhsm_log = simple_file("/var/log/rhsm/rhsm.log")
     rhsm_releasever = simple_file('/var/lib/rhsm/cache/releasever.json')
     rndc_status = simple_command("/usr/sbin/rndc status")
-    rpm_V_packages = simple_command("/bin/rpm -V coreutils procps procps-ng shadow-utils passwd sudo chrony", keep_rc=True)
+    rpm_V_packages = simple_command("/bin/rpm -V coreutils procps procps-ng shadow-utils passwd sudo chrony", keep_rc=True, signum=signal.SIGTERM)
     rsyslog_conf = glob_file(["/etc/rsyslog.conf", "/etc/rsyslog.d/*.conf"])
     samba = simple_file("/etc/samba/smb.conf")
 
     @datasource(Sap, HostContext)
-    def sap_sid(broker):
+    def sap_instance(broker):
         """
-        list: List of the SID of all SAP Instances.
+        list: List of all SAP Instances.
         """
         sap = broker[Sap]
-        return list(set(sap.sid(i).lower() for i in sap.all_instances))
+        return list(v for v in sap.values())
 
-    sap_hdb_version = foreach_execute(sap_sid, "/usr/bin/sudo -iu %sadm HDB version", keep_rc=True)
+    @datasource(sap_instance, HostContext)
+    def sap_hana_instance(broker):
+        """
+        list: List of the SAP HANA Instances.
+        """
+        sap = broker[DefaultSpecs.sap_instance]
+        return list(v for v in sap if v.type == 'HDB')
+
+    @datasource(sap_instance, HostContext)
+    def sap_sid(broker):
+        """
+        list: List of the SID of all the SAP Instances.
+        """
+        sap = broker[DefaultSpecs.sap_instance]
+        return list(set(h.sid.lower() for h in sap))
+
+    @datasource(sap_hana_instance, HostContext)
+    def sap_hana_sid(broker):
+        """
+        list: List of the SID of SAP HANA Instances.
+        """
+        hana = broker[DefaultSpecs.sap_hana_instance]
+        return list(set(h.sid.lower() for h in hana))
+
+    @datasource(sap_hana_instance, HostContext)
+    def sap_hana_sid_SID_nr(broker):
+        """
+        list: List of tuples (sid, SID, Nr) of SAP HANA Instances.
+        """
+        hana = broker[DefaultSpecs.sap_hana_instance]
+        return list((h.sid.lower(), h.sid, h.number) for h in hana)
+
+    @datasource(sap_sid, HostContext)
+    def ld_library_path_of_user(broker):
+        """
+        Returns: The list of LD_LIBRARY_PATH of specified users.
+                 Username is combined from SAP <SID> and 'adm' and is also stored.
+        """
+        sids = broker[DefaultSpecs.sap_sid]
+        ctx = broker[HostContext]
+        llds = []
+        for sid in sids:
+            usr = '{0}adm'.format(sid)
+            ret, vvs = ctx.shell_out("/bin/su -l {0} -c /bin/env".format(usr), keep_rc=True)
+            if ret != 0:
+                continue
+            for v in vvs:
+                if "LD_LIBRARY_PATH=" in v:
+                    llds.append('{0} {1}'.format(usr, v.split('=', 1)[-1]))
+        if llds:
+            return DatasourceProvider('\n'.join(llds), relative_path='insights_commands/echo_user_LD_LIBRARY_PATH')
+        raise SkipComponent
+
+    sap_hana_landscape = foreach_execute(sap_hana_sid_SID_nr, "/bin/su -l %sadm -c 'python /usr/sap/%s/HDB%s/exe/python_support/landscapeHostConfiguration.py'", keep_rc=True)
+    sap_hdb_version = foreach_execute(sap_hana_sid, "/bin/su -l %sadm -c 'HDB version'", keep_rc=True)
     saphostctl_getcimobject_sapinstance = simple_command("/usr/sap/hostctrl/exe/saphostctrl -function GetCIMObject -enuminstances SAPInstance")
     saphostexec_status = simple_command("/usr/sap/hostctrl/exe/saphostexec -status")
     saphostexec_version = simple_command("/usr/sap/hostctrl/exe/saphostexec -version")
@@ -787,17 +887,29 @@ class DefaultSpecs(Specs):
             return True
         raise SkipComponent
 
+    satellite_compute_resources = simple_command(
+        "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c 'select name, type from compute_resources' --csv",
+        deps=[is_satellite_server]
+    )
     satellite_content_hosts_count = simple_command(
         "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c 'select count(*) from hosts'",
         deps=[is_satellite_server]
     )
+    satellite_custom_ca_chain = simple_command(
+        '/usr/bin/awk \'BEGIN { pipe="openssl x509 -noout -subject -enddate"} /^-+BEGIN CERT/,/^-+END CERT/ { print | pipe } /^-+END CERT/ { close(pipe); printf("\\n")}\' /etc/pki/katello/certs/katello-server-ca.crt',
+    )
     satellite_mongodb_storage_engine = simple_command("/usr/bin/mongo pulp_database --eval 'db.serverStatus().storageEngine'")
     satellite_non_yum_type_repos = simple_command(
         "/usr/bin/mongo pulp_database --eval 'db.repo_importers.find({\"importer_type_id\": { $ne: \"yum_importer\"}}).count()'",
         deps=[[is_satellite_server, is_satellite_capsule]]
     )
+    satellite_settings = simple_command(
+        "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c \"select name, value, \\\"default\\\" from settings where name in ('destroy_vm_on_host_delete', 'unregister_delete_host')\" --csv",
+        deps=[is_satellite_server]
+    )
     satellite_version_rb = simple_file("/usr/share/foreman/lib/satellite/version.rb")
     satellite_custom_hiera = simple_file("/etc/foreman-installer/custom-hiera.yaml")
+    scheduler = glob_file("/sys/block/*/queue/scheduler")
     scsi = simple_file("/proc/scsi/scsi")
     scsi_eh_deadline = glob_file('/sys/class/scsi_host/host[0-9]*/eh_deadline')
     scsi_fwver = glob_file('/sys/class/scsi_host/host[0-9]*/fwrev')
@@ -904,11 +1016,11 @@ class DefaultSpecs(Specs):
     x86_retp_enabled = simple_file("sys/kernel/debug/x86/retp_enabled")
     xinetd_conf = glob_file(["/etc/xinetd.conf", "/etc/xinetd.d/*"])
     yum_conf = simple_file("/etc/yum.conf")
-    yum_list_available = simple_command("yum -C --noplugins list available")
+    yum_list_available = simple_command("yum -C --noplugins list available", signum=signal.SIGTERM)
     yum_log = simple_file("/var/log/yum.log")
-    yum_repolist = simple_command("/usr/bin/yum -C --noplugins repolist")
+    yum_repolist = simple_command("/usr/bin/yum -C --noplugins repolist", signum=signal.SIGTERM)
     yum_repos_d = glob_file("/etc/yum.repos.d/*.repo")
-    yum_updateinfo = simple_command("/usr/bin/yum -C updateinfo list")
+    yum_updateinfo = simple_command("/usr/bin/yum -C updateinfo list", signum=signal.SIGTERM)
     zipl_conf = simple_file("/etc/zipl.conf")
     rpm_format = format_rpm()
-    installed_rpms = simple_command("/bin/rpm -qa --qf '%s'" % rpm_format, context=HostContext)
+    installed_rpms = simple_command("/bin/rpm -qa --qf '%s'" % rpm_format, context=HostContext, signum=signal.SIGTERM)
